@@ -1,4 +1,5 @@
 # encoding: utf-8
+# typed: strict
 # frozen_string_literal: true
 
 # utilities.rb : General-purpose utility classes which don't fit anywhere else
@@ -19,13 +20,16 @@ class PDF::Reader
   # same time, we don't want to throw away thread safety We have two
   # interchangeable thread-safe cache implementations:
   class SynchronizedCache
+    #: () -> void
     def initialize
-      @cache = {}
-      @mutex = Mutex.new
+      @cache = {} #: Hash[Object, untyped]
+      @mutex = Mutex.new #: Mutex
     end
+    #: (Object) -> untyped
     def [](key)
       @mutex.synchronize { @cache[key] }
     end
+    #: (Object, (Object | nil)) -> untyped
     def []=(key,value)
       @mutex.synchronize { @cache[key] = value }
     end
