@@ -343,6 +343,19 @@ describe PDF::Reader, "integration specs" do
     end
   end
 
+  context "PDF has password mutiple of 32" do
+    let(:filename) { pdf_spec_file("encrypted_pdf_with_64_chars_string") }
+    let(:pass) { "8c24e855ef6f2eeabe9beb87478cef5ba14aa6e627364f3c7e2b1101bb791729" }
+
+    context "with the user pass" do
+      it "correctly extracts text" do
+        PDF::Reader.open(filename, :password => pass) do |reader|
+          expect(reader.page(1).text).to include("Dummy PDF file")
+        end
+      end
+    end
+  end
+
   context "encrypted_version1_revision2_40bit_rc4_user_pass_apples" do
     let(:filename) { pdf_spec_file("encrypted_version1_revision2_40bit_rc4_user_pass_apples") }
 
@@ -1423,7 +1436,7 @@ describe PDF::Reader, "integration specs" do
   context "PDF with page rotation of 270 degrees followed by matrix transformations to undo it" do
     let(:filename) { pdf_spec_file("rotate-then-undo") }
     let(:text) {
-      "This page uses matrix transformations to print text   sideways, " +
+      "This page uses matrix transformations to print text sideways, " +
       "then has a Rotate key to fix it"
     }
 
@@ -1634,7 +1647,7 @@ describe PDF::Reader, "integration specs" do
     it "extracts text correctly" do
       PDF::Reader.open(filename) do |reader|
         page = reader.page(1)
-        expect(page.text).to include("This PDF ha  sRotate:90 in the page")
+        expect(page.text).to include("This PDF has Rotate:90 in the page")
         expect(page.text).to include("metadata to get a landscape layout")
         expect(page.text).to include("and text in bottom right quadrant")
       end
@@ -1781,4 +1794,37 @@ describe PDF::Reader, "integration specs" do
       end
     end
   end
+
+  context "PDF with different font sizes" do
+    let(:filename) { pdf_spec_file("font_sizes") }
+
+    it "extracts font sizes correctly" do
+      PDF::Reader.open(filename) do |reader|
+        text_runs = reader.page(1).runs
+        expect(text_runs.size).to eql(4)
+        expect(text_runs.map(&:font_size)).to eql([90.0, 90.0, 12.0, 12.0])
+      end
+    end
+
+    it "excludes text by font size" do
+      PDF::Reader.open(filename) do |reader|
+        filter = {font_size: {greater_than: 20}}
+        expect(reader.page(1).text(exclude: filter)).to eql("small1\nsmall2")
+      end
+    end
+
+    it "includes only text by font size" do
+      PDF::Reader.open(filename) do |reader|
+        filter = {font_size: {greater_than: 20}}
+        expect(reader.page(1).text(only: filter)).to eql("BIG1\nBIG2")
+      end
+    end
+
+    it "excludes text when including text" do
+      PDF::Reader.open(filename) do |reader|
+        filter = {text: {include: "1"}}
+        expect(reader.page(1).text(exclude: filter)).to eql("BIG2\nsmall2")
+      end
+    end
+  end
 end
