@@ -1,3 +1,4 @@
+# typed: false
 # coding: utf-8
 
 describe PDF::Reader::Page do
@@ -70,6 +71,45 @@ describe PDF::Reader::Page do
     end
   end
 
+  describe "#rectangles" do
+    let!(:page)    { browser.page(1) }
+    let!(:browser) { PDF::Reader.new(pdf_spec_file("all_page_boxes_exist")) }
+
+    it "returns a hash of all the different boxes" do
+      expect(page.attributes[:ArtBox]).to_not be_empty
+      expect(page.attributes[:BleedBox]).to_not be_empty
+      expect(page.attributes[:CropBox]).to_not be_empty
+      expect(page.attributes[:MediaBox]).to_not be_empty
+      expect(page.attributes[:TrimBox]).to_not be_empty
+
+      expect(page.rectangles).to eq(
+        {
+          ArtBox: PDF::Reader::Rectangle.new(0, 0, 612, 792),
+          BleedBox: PDF::Reader::Rectangle.new(0, 0, 612, 792),
+          CropBox: PDF::Reader::Rectangle.new(0, 0, 612, 792),
+          MediaBox: PDF::Reader::Rectangle.new(0, 0, 612, 792),
+          TrimBox: PDF::Reader::Rectangle.new(0, 0, 612, 792),
+        }
+      )
+    end
+
+    context "mediabox and cropbox are references" do
+      let!(:browser) { PDF::Reader.new(pdf_spec_file("mediabox_and_cropbox_are_references")) }
+
+      it "returns a non-reference for the dimensions of the boxes" do
+        expect(page.rectangles).to eq(
+          {
+            ArtBox: PDF::Reader::Rectangle.new(0, 0, 612, 792),
+            BleedBox: PDF::Reader::Rectangle.new(0, 0, 612, 792),
+            CropBox: PDF::Reader::Rectangle.new(0, 0, 612, 792),
+            MediaBox: PDF::Reader::Rectangle.new(0, 0, 612, 792),
+            TrimBox: PDF::Reader::Rectangle.new(0, 0, 612, 792),
+          }
+        )
+      end
+    end
+  end
+
   describe "#walk" do
 
     context "with page 1 of cairo-basic.pdf" do
@@ -111,6 +151,26 @@ describe PDF::Reader::Page do
         expect(callbacks.size).to eql(16)
         expect(callbacks.first).to eql(:page=)
       end
+
+      context "with a receiver that implements a method not type checked by ValidatingReceiver" do
+
+        before do
+          # This test is speecifically for confirming a receiver method is called, even if that
+          # method isn't one that ValidatingReceiver is type checking. If the following assertion
+          # ever fails, then we should update this spec to a different method not mentioned in
+          # ValidatingReceiver
+          expect(PDF::Reader::ValidatingReceiver.methods).to_not include(
+            :set_rgb_color_for_nonstroking
+          )
+        end
+
+        it "calls the receiver method as expected" do
+          receiver = double(set_rgb_color_for_nonstroking: true)
+          page.walk(receiver)
+          expect(receiver).to have_received(:set_rgb_color_for_nonstroking).twice
+        end
+      end
+
     end
   end
 
