@@ -1,3 +1,4 @@
+# typed: false
 # coding: utf-8
 
 describe PDF::Reader::PageState do
@@ -208,6 +209,16 @@ describe PDF::Reader::PageState do
         expect(state.trm_transform(1,1)).to eq([17, 22])
       end
     end
+
+    context "without begin_text first (out of order)" do
+      let!(:state)  {PDF::Reader::PageState.new(page) }
+
+      it "doesn't raise an exception" do
+        expect {
+          state.move_text_position(5, 10)
+        }.to_not raise_error
+      end
+    end
   end
 
   describe "#move_text_position_and_set_leading" do
@@ -236,6 +247,15 @@ describe PDF::Reader::PageState do
         expect(state.clone_state[:text_leading]).to eq(-10)
       end
     end
+    context "without begin_text first (out of order)" do
+      let!(:state)  {PDF::Reader::PageState.new(page) }
+
+      it "doesn't raise an exception" do
+        expect {
+          state.move_text_position_and_set_leading(5, 10)
+        }.to_not raise_error
+      end
+    end
   end
 
   describe "#set_text_matrix_and_text_line_matrix" do
@@ -277,6 +297,15 @@ describe PDF::Reader::PageState do
         expect(state.trm_transform(1,1)).to eq([12, -3])
       end
     end
+    context "without begin_text first (out of order)" do
+      let!(:state)  {PDF::Reader::PageState.new(page) }
+
+      it "doesn't raise an exception" do
+        expect {
+          state.move_to_start_of_next_line
+        }.to_not raise_error
+      end
+    end
   end
 
   describe "#move_to_next_line_and_show_text" do
@@ -298,6 +327,15 @@ describe PDF::Reader::PageState do
         expect(state.trm_transform(1,1)).to eq([12, -3])
       end
     end
+    context "without begin_text first (out of order)" do
+      let!(:state)  {PDF::Reader::PageState.new(page) }
+
+      it "doesn't raise an exception" do
+        expect {
+          state.move_to_next_line_and_show_text("Foo")
+        }.to_not raise_error
+      end
+    end
   end
 
   describe "#move_to_next_line_and_show_text" do
@@ -351,6 +389,47 @@ describe PDF::Reader::PageState do
         expect(state.trm_transform(1,1)).to eq([12, 12])
       end
     end
+    context "without begin_text first (out of order)" do
+      let!(:state)  {PDF::Reader::PageState.new(page) }
+
+      it "doesn't raise an exception" do
+        expect {
+          state.set_spacing_next_line_show_text(10, 20, "test")
+        }.to_not raise_error
+      end
+    end
+  end
+
+  describe "#ctm_transform" do
+    # ctm_transform is mostly verified as correct via assertions in all the other specs of this
+    # class - it's one of the primary ways we can see the visible state. However we need to check
+    # some error conditions here
+
+    context "with an empty page" do
+      let!(:state)  {PDF::Reader::PageState.new(page) }
+
+      it "is a no-op" do
+        expect(state.trm_transform(0,0)).to eq([0, 0])
+      end
+    end
+
+  end
+
+  describe "#trm_transform" do
+    # trm_transform is mostly verified as correct via assertions in all the other specs of this
+    # class - it's one of the primary ways we can see the visible state. However we need to check
+    # some error conditions here
+
+    context "without begin_text first (out of order)" do
+      let!(:state)  {PDF::Reader::PageState.new(page) }
+
+      it "doesn't raise an exception" do
+        expect {
+          state.trm_transform(0,0)
+        }.to_not raise_error
+      end
+    end
+
   end
 
   describe "#process_glyph_displacement" do
@@ -468,10 +547,10 @@ describe PDF::Reader::PageState do
                 it "alters the text matrix" do
                   state.process_glyph_displacement(2, 2, true)
 
-                  expect(state.trm_transform(0,0)).to eq([64.976, 700])
-                  expect(state.trm_transform(0,1)).to eq([64.976, 712])
-                  expect(state.trm_transform(1,0)).to eq([76.976, 700])
-                  expect(state.trm_transform(1,1)).to eq([76.976, 712])
+                  expect(state.trm_transform(0,0)).to eq([63.976, 700])
+                  expect(state.trm_transform(0,1)).to eq([63.976, 712])
+                  expect(state.trm_transform(1,0)).to eq([75.976, 700])
+                  expect(state.trm_transform(1,1)).to eq([75.976, 712])
                 end
               end
             end
@@ -512,10 +591,10 @@ describe PDF::Reader::PageState do
                 it "alters the text matrix" do
                   state.process_glyph_displacement(2, 2, false)
 
-                  expect(state.trm_transform(0,0)).to eq([64.976, 700])
-                  expect(state.trm_transform(0,1)).to eq([64.976, 712])
-                  expect(state.trm_transform(1,0)).to eq([76.976, 700])
-                  expect(state.trm_transform(1,1)).to eq([76.976, 712])
+                  expect(state.trm_transform(0,0)).to eq([63.976, 700])
+                  expect(state.trm_transform(0,1)).to eq([63.976, 712])
+                  expect(state.trm_transform(1,0)).to eq([75.976, 700])
+                  expect(state.trm_transform(1,1)).to eq([75.976, 712])
                 end
               end
               context "a word boundary" do
@@ -523,10 +602,10 @@ describe PDF::Reader::PageState do
                 it "alters the text matrix" do
                   state.process_glyph_displacement(2, 2, true)
 
-                  expect(state.trm_transform(0,0)).to eq([64.976, 700])
-                  expect(state.trm_transform(0,1)).to eq([64.976, 712])
-                  expect(state.trm_transform(1,0)).to eq([76.976, 700])
-                  expect(state.trm_transform(1,1)).to eq([76.976, 712])
+                  expect(state.trm_transform(0,0)).to eq([63.976, 700])
+                  expect(state.trm_transform(0,1)).to eq([63.976, 712])
+                  expect(state.trm_transform(1,0)).to eq([75.976, 700])
+                  expect(state.trm_transform(1,1)).to eq([75.976, 712])
                 end
               end
             end
@@ -565,10 +644,10 @@ describe PDF::Reader::PageState do
                 it "alters the text matrix" do
                   state.process_glyph_displacement(2, 2, false)
 
-                  expect(state.trm_transform(0,0)).to eq([64.976, 700])
-                  expect(state.trm_transform(0,1)).to eq([64.976, 712])
-                  expect(state.trm_transform(1,0)).to eq([76.976, 700])
-                  expect(state.trm_transform(1,1)).to eq([76.976, 712])
+                  expect(state.trm_transform(0,0)).to eq([63.976, 700])
+                  expect(state.trm_transform(0,1)).to eq([63.976, 712])
+                  expect(state.trm_transform(1,0)).to eq([75.976, 700])
+                  expect(state.trm_transform(1,1)).to eq([75.976, 712])
                 end
               end
               context "a word boundary" do
@@ -576,10 +655,10 @@ describe PDF::Reader::PageState do
                 it "alters the text matrix" do
                   state.process_glyph_displacement(2, 2, true)
 
-                  expect(state.trm_transform(0,0)).to eq([65.976, 700])
-                  expect(state.trm_transform(0,1)).to eq([65.976, 712])
-                  expect(state.trm_transform(1,0)).to eq([77.976, 700])
-                  expect(state.trm_transform(1,1)).to eq([77.976, 712])
+                  expect(state.trm_transform(0,0)).to eq([63.976, 700])
+                  expect(state.trm_transform(0,1)).to eq([63.976, 712])
+                  expect(state.trm_transform(1,0)).to eq([75.976, 700])
+                  expect(state.trm_transform(1,1)).to eq([75.976, 712])
                 end
               end
             end
